@@ -40,7 +40,7 @@ fn execute_uncommitted(sql_id: &str, transaction: &mut Transaction, item: &HashM
     let sql = build_sql(sql_id, "", item);
     // info!("{}",sql);
     Ok(match transaction.batch_execute(sql.as_str()) {
-        Ok(t) =>  item.len(),
+        Ok(t) =>  1,
         Err(e) => {
             error!("{}\n{:?}", sql, e);
             return Err(PgDaoError::ExecutionError(e.to_string()))
